@@ -21,6 +21,7 @@ from unit.api.authorization_request_resource import AuthorizationRequestResource
 from unit.api.account_end_of_day_resource import AccountEndOfDayResource
 from unit.api.checkDeposit_resource import CheckDepositResource
 from unit.api.dispute_resource import DisputeResource
+from unit.api.reward_resource import RewardResource
 
 __all__ = ["api", "models", "utils"]
 
@@ -50,3 +51,4 @@ class Unit(object):
         self.account_end_of_day = AccountEndOfDayResource(api_url, token)
         self.checkDeposits = CheckDepositResource(api_url, token)
         self.disputes = DisputeResource(api_url, token)
+        self.rewards = RewardResource(api_url, token)
