@@ -61,3 +61,13 @@ class ApplicationResource(BaseResource):
             return UnitResponse[ApplicationDocumentDTO](DtoDecoder.decode(data), None)
         else:
             return UnitError.from_json_api(response.json())
+
+    def update(self, request: PatchApplicationRequest) -> Union[UnitResponse[ApplicationDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().patch(f"{self.resource}/{request.application_id}", payload)
+        if super().is_20x(response.status_code):
+            data = response.json().get("data")
+            return UnitResponse[ApplicationDTO](DtoDecoder.decode(data), None)
+        else:
+            return UnitError.from_json_api(response.json())
+
