@@ -16,8 +16,9 @@ class EventResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[EventDTO]], UnitError]:
-        response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
+    def list(self, params: ListEventParams = None) -> Union[UnitResponse[List[EventDTO]], UnitError]:
+        params = params or ListEventParams()
+        response = super().get(self.resource, params.to_dict())
         if super().is_20x(response.status_code):
             data = response.json().get("data")
             return UnitResponse[EventDTO](DtoDecoder.decode(data), None)
