@@ -17,7 +17,7 @@ class BasePayment(object):
 class AchPaymentDTO(BasePayment):
     def __init__(self, id: str, created_at: datetime, status: PaymentStatus, counterparty: Counterparty, direction: str,
                  description: str, amount: int, addenda: Optional[str], reason: Optional[str],
-                 settlement_date: Optional[datetime], tags: Optional[Dict[str, str]],
+                 settlement_date: Optional[date], tags: Optional[Dict[str, str]],
                  relationships: Optional[Dict[str, Relationship]]):
         BasePayment.__init__(self, id, created_at, status, direction, description, amount, reason, tags, relationships)
         self.type = 'achPayment'
@@ -27,10 +27,10 @@ class AchPaymentDTO(BasePayment):
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
-        settlement_date = date_utils.to_date(attributes.get("settlementDate")) if attributes.get("settlementDate") else None
         return AchPaymentDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["status"],
-                             Counterparty.from_json_api(attributes["counterparty"]), attributes["direction"], attributes["description"],
-                             attributes["amount"], attributes.get("addenda"), attributes.get("reason"), settlement_date,
+                             Counterparty.from_json_api(attributes["counterparty"]), attributes["direction"],
+                             attributes["description"], attributes["amount"], attributes.get("addenda"),
+                             attributes.get("reason"), date_utils.to_date(attributes.get("settlementDate")),
                              attributes.get("tags"), relationships)
 
 class BookPaymentDTO(BasePayment):
@@ -50,7 +50,7 @@ class WirePaymentDTO(BasePayment):
     def __init__(self, id: str, created_at: datetime, status: PaymentStatus, counterparty: WireCounterparty,
                  direction: str, description: str, amount: int, reason: Optional[str], tags: Optional[Dict[str, str]],
                  relationships: Optional[Dict[str, Relationship]]):
-        BasePayment.__init__(self, id, created_at, direction, description, amount, reason, tags, relationships)
+        BasePayment.__init__(self, id, created_at, status, direction, description, amount, reason, tags, relationships)
         self.type = "wirePayment"
         self.attributes["counterparty"] = counterparty
 
@@ -63,7 +63,8 @@ class WirePaymentDTO(BasePayment):
 
 class BillPaymentDTO(BasePayment):
     def __init__(self, id: str, created_at: datetime, status: PaymentStatus, direction: str, description: str,
-                 amount: int, tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
+                 amount: int, reason: Optional[str], tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BasePayment.__init__(self, id, created_at, status, direction, description, amount, reason, tags, relationships)
         self.type = 'billPayment'
 
@@ -77,11 +78,13 @@ PaymentDTO = Union[AchPaymentDTO, BookPaymentDTO, WirePaymentDTO, BillPaymentDTO
 
 AchReceivedPaymentStatus = Literal["Pending", "Advanced", "Completed", "Returned"]
 
+
 class AchReceivedPaymentDTO(object):
-    def __init__(self, id: str, created_at: datetime, status: AchReceivedPaymentStatus, was_advanced: bool,
-                 completion_date: datetime, return_reason: Optional[str], amount: int, description: str,
+    def __init__(self, _id: str, created_at: datetime, status: AchReceivedPaymentStatus, was_advanced: bool,
+                 completion_date: date, return_reason: Optional[str], amount: int, description: str,
                  addenda: Optional[str], company_name: str, counterparty_routing_number: str, trace_number: str,
                  sec_code: Optional[str], tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
+        self.id = _id
         self.type = "achReceivedPayment"
         self.attributes = {"createdAt": created_at, "status": status, "wasAdvanced": was_advanced,
                            "completionDate": completion_date, "returnReason": return_reason, "description": description,
@@ -93,8 +96,8 @@ class AchReceivedPaymentDTO(object):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AchReceivedPaymentDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["status"],
-                                     attributes["wasAdvanced"], attributes["completionDate"],
-                                     attributes.get("returnReason"),attributes["amount"], attributes["description"],
+                                     attributes["wasAdvanced"], date_utils.to_date(attributes["completionDate"]),
+                                     attributes.get("returnReason"), attributes["amount"], attributes["description"],
                                      attributes.get("addenda"), attributes.get("companyName"),
                                      attributes.get("counterpartyRoutingNumber"), attributes.get("traceNumber"),
                                      attributes.get("secCode"), attributes.get("tags"), relationships)
