@@ -6,12 +6,12 @@ AchReturnReason = Literal["Unauthorized"]
 
 
 class ReturnReceivedAchTransactionRequest(object):
-    def __init__(self, transaction_id: str, reason: AchReturnReason, relationships: [dict[str, Relationship]]):
+    def __init__(self, transaction_id: str, reason: AchReturnReason, relationships: [Dict[str, Relationship]]):
         self.transaction_id = transaction_id
         self.reason = reason
         self.relationships = relationships
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "returnAch",
